==> plugin-mq-client-2.0.11-20200908.083842-6-sources.jar: com/ohaotian/plugin/mq/proxy/config/ApolloConfigVO.java <==
package com.ohaotian.plugin.mq.proxy.config;


import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;


@Component
public class ApolloConfigVO {
    @Value("${mq.enable:default}")
    private String enable;
    @Value("${mq.onsAddr:default}")
    private String onsAddr;
    @Value("${mq.sendMsgTimeoutMillis:default}")
    private String sendMsgTimeoutMillis;
    @Value("${mq.strategy:default}")
    private String strategy;
    @Value("${mq.accessKey:default}")
    private String accessKey;
    @Value("${mq.secretKey:default}")
    private String secretKey;
    @Value("${mq.topic:default}")
    private String topic;
    @Value("${mq.tag:default}")
    private String tag;
    @Value("${mq.supportGID:default}")
    private  String supportGID;
    @Value("${mq.rocket.namesrvaddr:default}")
    private String rocketNamesrvaddr;

    public String getRocketNamesrvaddr() {
        return rocketNamesrvaddr;
    }

    public void setRocketNamesrvaddr(String rocketNamesrvaddr) {
        this.rocketNamesrvaddr = rocketNamesrvaddr;
    }

    public String getSupportGID() {
        return supportGID;
    }

    public void setSupportGID(String supportGID) {
        this.supportGID = supportGID;
    }

    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }

    public String getOnsAddr() {
        return onsAddr;
    }

    public void setOnsAddr(String onsAddr) {
        this.onsAddr = onsAddr;
    }

    public String getSendMsgTimeoutMillis() {
        return sendMsgTimeoutMillis;
    }

    public void setSendMsgTimeoutMillis(String sendMsgTimeoutMillis) {
        this.sendMsgTimeoutMillis = sendMsgTimeoutMillis;
    }

    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public String getAccessKey() {
        return accessKey;
    }

    public void setAccessKey(String accessKey) {
        this.accessKey = accessKey;
    }

    public String getSecretKey() {
        return secretKey;
    }

    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }
}

==> plugin-mq-client-2.0.18-20211216.082552-1-sources.jar: com/ohaotian/plugin/mq/proxy/config/ApolloConfigVO.java <==
package com.ohaotian.plugin.mq.proxy.config;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

@Configuration
public class ApolloConfigVO {
    @Value("${mq.enable:true}")
    private String enable;
    @Value("${mq.onsAddr:http://onsaddr.mq-internet-access.mq-internet.aliyuncs.com:80}")
    private String onsAddr;
    @Value("${mq.sendMsgTimeoutMillis:1000}")
    private String sendMsgTimeoutMillis;
    @Value("${mq.strategy:AliyunMQ}")
    private String strategy;
    @Value("${mq.accessKey:LTAIWuMii0ORicCm}")
    private String accessKey;
    @Value("${mq.secretKey:9F4XdVPf0IvGVRHg1bidsnPRrwR64I}")
    private String secretKey;
    @Value("${mq.topic:DEVZT_TEST_TOPIC}")
    private String topic;
    @Value("${mq.tag:myDemo}")
    private String tag;
    @Value("${mq.supportGID:GID_ZT_TEST_MQ}")
    private  String supportGID;
    @Value("${mq.rocket.namesrvaddr:http://onsaddr.mq-internet-access.mq-internet.aliyuncs.com:80}")
    private String rocketNamesrvaddr;

    public String getRocketNamesrvaddr() {
        return rocketNamesrvaddr;
    }

    public void setRocketNamesrvaddr(String rocketNamesrvaddr) {
        this.rocketNamesrvaddr = rocketNamesrvaddr;
    }

    public String getSupportGID() {
        return supportGID;
    }

    public void setSupportGID(String supportGID) {
        this.supportGID = supportGID;
    }

    public String getEnable() {
        return enable;
    }

    public void setEnable(String enable) {
        this.enable = enable;
    }

    public String getOnsAddr() {
        return onsAddr;
    }

    public void setOnsAddr(String onsAddr) {
        this.onsAddr = onsAddr;
    }

    public String getSendMsgTimeoutMillis() {
        return sendMsgTimeoutMillis;
    }

    public void setSendMsgTimeoutMillis(String sendMsgTimeoutMillis) {
        this.sendMsgTimeoutMillis = sendMsgTimeoutMillis;
    }

    public String getStrategy() {
        return strategy;
    }

    public void setStrategy(String strategy) {
        this.strategy = strategy;
    }

    public String getAccessKey() {
        return accessKey;
    }

    public void setAccessKey(String accessKey) {
        this.accessKey = accessKey;
    }

    public String getSecretKey() {
        return secretKey;
    }

    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }

    public String getTopic() {
        return topic;
    }

    public void setTopic(String topic) {
        this.topic = topic;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    @Override
    public String toString() {
        return "ApolloConfigVO{" +
                "enable='" + enable + '\'' +
                ", onsAddr='" + onsAddr + '\'' +
                ", sendMsgTimeoutMillis='" + sendMsgTimeoutMillis + '\'' +
                ", strategy='" + strategy + '\'' +
                ", accessKey='" + accessKey + '\'' +
                ", secretKey='" + secretKey + '\'' +
                ", topic='" + topic + '\'' +
                ", tag='" + tag + '\'' +
                ", supportGID='" + supportGID + '\'' +
                ", rocketNamesrvaddr='" + rocketNamesrvaddr + '\'' +
                '}';
    }
}
